select.filter-autocomplete {
  width: 20em;
}

.select2 {
  border: 1px solid var(--border-color);
  color: var(--body-fg);
  background-color: var(--body-bg);
}

.select2-dropdown, .select2-search__field {
  border: 1px solid var(--border-color);
  border-radius: 4px;
  color: var(--body-fg);
  background-color: var(--body-bg);
}

.select2-selection__rendered {
  color: var(--body-fg);
  background-color: var(--body-bg);
}

.select2-container--filter-autocomplete.select2-container {
  min-height: 30px;
}

.select2-container--filter-autocomplete .select2-selection--single,
.select2-container--filter-autocomplete .select2-selection--multiple {
  min-height: 30px;
  padding: 0;
}

.select2-container--filter-autocomplete.select2-container--focus .select2-selection,
.select2-container--filter-autocomplete.select2-container--open .select2-selection {
  border-color: #999;
  min-height: 30px;
}

.select2-container--filter-autocomplete.select2-container--focus .select2-selection.select2-selection--single,
.select2-container--filter-autocomplete.select2-container--open .select2-selection.select2-selection--single {
  padding: 0;
}

.select2-container--filter-autocomplete.select2-container--focus .select2-selection.select2-selection--multiple,
.select2-container--filter-autocomplete.select2-container--open .select2-selection.select2-selection--multiple {
  padding: 0;
}

.select2-container--filter-autocomplete .select2-selection--single {
  border-radius: 4px;
}

.select2-container--filter-autocomplete .select2-selection--single .select2-selection__rendered {
  line-height: 30px;
}

.select2-container--filter-autocomplete .select2-selection--single .select2-selection__clear {
  cursor: pointer;
  float: right;
  font-weight: bold;
}

.select2-container--filter-autocomplete .select2-selection--single .select2-selection__arrow {
  height: 26px;
  position: absolute;
  top: 1px;
  right: 1px;
  width: 20px;
}

.select2-container--filter-autocomplete .select2-selection--single .select2-selection__arrow b {
  border-color: #888 transparent transparent transparent;
  border-style: solid;
  border-width: 5px 4px 0 4px;
  height: 0;
  left: 50%;
  margin-left: -4px;
  margin-top: -2px;
  position: absolute;
  top: 50%;
  width: 0;
}

.select2-container--filter-autocomplete[dir=rtl] .select2-selection--single .select2-selection__clear {
  float: left;
}

.select2-container--filter-autocomplete[dir=rtl] .select2-selection--single .select2-selection__arrow {
  left: 1px;
  right: auto;
}

.select2-container--filter-autocomplete.select2-container--disabled .select2-selection--single {
  background-color: #eee;
  cursor: default;
}

.select2-container--filter-autocomplete.select2-container--disabled .select2-selection--single .select2-selection__clear {
  display: none;
}

.select2-container--filter-autocomplete.select2-container--open .select2-selection--single .select2-selection__arrow b {
  border-color: transparent transparent #888 transparent;
  border-width: 0 4px 5px 4px;
}

.select2-container--filter-autocomplete .select2-selection--multiple {
  border: 1px solid #ccc;
  border-radius: 4px;
  cursor: text;
}

.select2-container--filter-autocomplete .select2-selection--multiple .select2-selection__rendered {
  box-sizing: border-box;
  list-style: none;
  margin: 0;
  padding: 0 5px;
  width: 100%;
}

.select2-container--filter-autocomplete .select2-selection--multiple .select2-selection__rendered li {
  list-style: none;
}

.select2-container--filter-autocomplete .select2-selection--multiple .select2-selection__placeholder {
  margin-top: 5px;
  float: left;
}

.select2-container--filter-autocomplete .select2-selection--multiple .select2-selection__clear {
  cursor: pointer;
  float: right;
  font-weight: bold;
  margin: 5px;
}

.select2-container--filter-autocomplete .select2-selection--multiple .select2-selection__choice {
  background-color: #e4e4e4;
  border: 1px solid #ccc;
  border-radius: 4px;
  cursor: default;
  float: left;
  margin-right: 5px;
  margin-top: 5px;
  padding: 0 5px;
}

.select2-container--filter-autocomplete .select2-selection--multiple .select2-selection__choice__remove {
  color: #999;
  cursor: pointer;
  display: inline-block;
  font-weight: bold;
  margin-right: 2px;
}

.select2-container--filter-autocomplete .select2-selection--multiple .select2-selection__choice__remove:hover {
  color: #333;
}

.select2-container--filter-autocomplete[dir=rtl] .select2-selection--multiple .select2-selection__choice, .select2-container--filter-autocomplete[dir=rtl] .select2-selection--multiple .select2-selection__placeholder, .select2-container--filter-autocomplete[dir=rtl] .select2-selection--multiple .select2-search--inline {
  float: right;
}

.select2-container--filter-autocomplete[dir=rtl] .select2-selection--multiple .select2-selection__choice {
  margin-left: 5px;
  margin-right: auto;
}

.select2-container--filter-autocomplete[dir=rtl] .select2-selection--multiple .select2-selection__choice__remove {
  margin-left: 2px;
  margin-right: auto;
}

.select2-container--filter-autocomplete.select2-container--focus .select2-selection--multiple {
  border: solid #999 1px;
  outline: 0;
}

.select2-container--filter-autocomplete.select2-container--disabled .select2-selection--multiple {
  background-color: #eee;
  cursor: default;
}

.select2-container--filter-autocomplete.select2-container--disabled .select2-selection__choice__remove {
  display: none;
}

.select2-container--filter-autocomplete.select2-container--open.select2-container--above .select2-selection--single, .select2-container--filter-autocomplete.select2-container--open.select2-container--above .select2-selection--multiple {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.select2-container--filter-autocomplete.select2-container--open.select2-container--below .select2-selection--single, .select2-container--filter-autocomplete.select2-container--open.select2-container--below .select2-selection--multiple {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

.select2-container--filter-autocomplete .select2-search--dropdown .select2-search__field {
  border: 1px solid #ccc;
}

.select2-container--filter-autocomplete .select2-search--inline .select2-search__field {
  background: transparent;
  border: none;
  outline: 0;
  box-shadow: none;
  -webkit-appearance: textfield;
}

.select2-container--filter-autocomplete .select2-results > .select2-results__options {
  max-height: 200px;
  overflow-y: auto;
}

.select2-container--filter-autocomplete .select2-results__option[role=group] {
  padding: 0;
}

.select2-container--filter-autocomplete .select2-results__option[aria-disabled=true] {
  color: #999;
}

.select2-container--filter-autocomplete .select2-results__option[aria-selected=true] {
  background-color: var(--body-bg);
}

.select2-container--filter-autocomplete .select2-results__option .select2-results__option {
  padding-left: 1em;
}

.select2-container--filter-autocomplete .select2-results__option .select2-results__option .select2-results__group {
  padding-left: 0;
}

.select2-container--filter-autocomplete .select2-results__option .select2-results__option .select2-results__option {
  margin-left: -1em;
  padding-left: 2em;
}

.select2-container--filter-autocomplete .select2-results__option .select2-results__option .select2-results__option .select2-results__option {
  margin-left: -2em;
  padding-left: 3em;
}

.select2-container--filter-autocomplete .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option {
  margin-left: -3em;
  padding-left: 4em;
}

.select2-container--filter-autocomplete .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option {
  margin-left: -4em;
  padding-left: 5em;
}

.select2-container--filter-autocomplete .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option {
  margin-left: -5em;
  padding-left: 6em;
}

.select2-container--filter-autocomplete .select2-results__option--highlighted[aria-selected] {
  background-color: #79aec8;
  color: var(--body-fg);
}

.select2-container--filter-autocomplete .select2-results__group {
  cursor: default;
  display: block;
  padding: 6px;
}

#changelist-filter li a.adminfilters.button {
  border: 1px solid #b8b8b8;
  color: white;
  padding: 2px;
  border-radius: 20px;
  text-align: center;
}

#changelist-filter li a.adminfilters.button.filter {
  background-color: #888;
}
#changelist-filter li a.adminfilters.button.filter:hover {
  background-color: #747474;
}
#changelist-filter li a.adminfilters.button.delete {
  background-color: #e1adad;
}
#changelist-filter li a.adminfilters.button.delete:hover {
  background-color: #dc6c6c;
}
#changelist-filter li a.adminfilters.button.clear {
  background-color: #79aec8;
}
#changelist-filter li a.adminfilters.button.clear:hover {
  background-color: #417690;
}
#changelist-filter li a.adminfilters.button.disabled {
  background-color: #d3caca !important;
}

#changelist-filter li input:disabled {
  background-color: #eae2e2;
}

#changelist-filter div.adminfilters.box.error {
  background-color: #f8bcbc;
}

#changelist-filter div.adminfilters.box.collapse div.filter-content {
  display: none;
}

#changelist-filter ul.adminfilters textarea {
  resize: vertical;
}

#changelist .opener {
  background: url("../admin/img/sorting-icons.svg");
  background-repeat: no-repeat;
  width: 14px;
  height: 14px;
  display: inline-block;
  background-size: 14px auto;
  background-position: 0 -28px;
  top: 1px;
  cursor: pointer;
  /*background-position: 0 -56px;*/
}

@media (prefers-color-scheme: dark) {
  .select2 {
    color: var(--body-fg);
    background-color: var(--body-bg);
  }
}

/*# sourceMappingURL=adminfilters.css.map */
